@@ -11,6 +11,8 @@
  * $Id: setup.php,v 1.2 2003/02/16 04:20:45 dminor Exp $
  */
 
+define('SM_PATH','../../');
+
 function squirrelmail_plugin_init_vacation() {
 
     global $squirrelmail_plugin_hooks;
@@ -22,11 +24,11 @@ function squirrelmail_plugin_init_vacation() {
 function squirrelmail_vacation_optpage_register_block(){
     global $optpage_blocks;
     
-    include_once("../plugins/vacation/config.php");
+    include_once(SM_PATH . "plugins/vacation/config.php");
     
     $optpage_blocks[] = array(
         "name" => $vac_title,
-        "url"  => "../plugins/vacation/vac_init.php",
+        "url"  => SM_PATH . "plugins/vacation/vac_init.php",
         "desc" => $vac_setup_message,
         "js"   => false
     );
